.. ai-python docs documentation master file, created by
   sphinx-quickstart on Thu May  5 14:06:45 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Welcome to ai-python docs's documentation!
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
